==> af-common-socket-2.14.7-sources.jar: com/af/v4/system/common/socket/core/channel/AbstractChannelHandler.java <==
package com.af.v4.system.common.socket.core.channel;

import com.af.v4.system.common.core.exception.LogicException;
import com.af.v4.system.common.core.proxy.logic.ILogicServiceProxy;
import com.af.v4.system.common.core.utils.SpringUtils;
import com.af.v4.system.common.log.enums.BusinessType;
import com.af.v4.system.common.log.enums.OperatorType;
import com.af.v4.system.common.log.service.LogResolveService;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.SocketServerManager;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.enums.MsgTypeEnum;
import com.af.v4.system.common.socket.core.client.ClientManager;
import java.nio.charset.StandardCharsets;
import io.netty.buffer.ByteBuf;
import io.netty.channel.Channel;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.handler.timeout.IdleState;
import io.netty.handler.timeout.IdleStateEvent;
import io.netty.channel.socket.DatagramChannel;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.InetSocketAddress;
import java.net.SocketAddress;

public abstract class AbstractChannelHandler<T> extends SimpleChannelInboundHandler<T> {

    private static final Logger LOGGER = LoggerFactory.getLogger(AbstractChannelHandler.class);

    /**
     * 通道创建就绪后触发
     * @param ctx 通道
     * @throws Exception 抛出
     */
    @Override
    public void channelActive(ChannelHandlerContext ctx) throws Exception {
        String channelId = ctx.channel().id().asLongText();
        SocketAddress socketAddress = ctx.channel().remoteAddress();
        String address;
        if (socketAddress == null) {
            address = "-";
        } else {
            address = socketAddress.toString();
        }
        LOGGER.info("channelId:{}, address:{}, 成功建立连接", channelId, address);
        initChannelData(ctx);
        super.channelActive(ctx);
    }

    /**
     * 当通道有读取事件时，会触发
     * @param ctx 通道
     * @param msg 消息
     */
    @Override
    protected final void channelRead0(ChannelHandlerContext ctx, T msg) {
        String channelId = ctx.channel().id().asLongText();
        LOGGER.info("channelId:{}, 收到消息", channelId);
        ScopedValue.where(ClientManager.getChannelScopedValue(), channelId).run(() -> {
            if (ClientManager.getChannelData() == null) {
                initChannelData(ctx);
            }
            // 执行读方法
            read(ctx, msg);
        });
    }

    @Override
    public void channelInactive(ChannelHandlerContext ctx) throws Exception {
        LOGGER.info("channelId:{}, 触发断线", ctx.channel().id().asLongText());
        closeChannel(ctx);
        super.channelInactive(ctx);
    }

    @Override
    public void userEventTriggered(ChannelHandlerContext ctx, Object evt) throws Exception {
        if (evt instanceof IdleStateEvent idleStateEvent) {
            IdleState state = idleStateEvent.state();
            LOGGER.info("channelId:{}, 触发空闲断开事件:{}", ctx.channel().id().asLongText(), state);
            closeChannel(ctx);
        }
        super.userEventTriggered(ctx, evt);
    }

    /**
     * 处理异常, 一般是需要关闭通道
     * @param ctx 通道
     * @param cause 异常
     */
    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) {
        String channelId = ctx.channel().id().asLongText();
        LOGGER.error("channelId:{} 发生异常：{}", channelId, cause.getMessage());
        try {
            String plain = "500";
            ScopedValue.where(ClientManager.getChannelScopedValue(), channelId).run(() -> {
                MsgTypeEnum encodeType = ClientManager.getConfig().getEncodeType();
                String payload = switch (encodeType) {
                    case HEX -> ConvertTools.byteToHexStr(plain.getBytes(StandardCharsets.UTF_8));
                    case BASE64 -> ConvertTools.base64Encode(plain.getBytes(StandardCharsets.UTF_8));
                    case HEX_BASE64 -> {
                        String b64 = ConvertTools.base64Encode(plain.getBytes(StandardCharsets.UTF_8));
                        yield ConvertTools.byteToHexStr(b64.getBytes(StandardCharsets.UTF_8));
                    }
                    default -> plain;
                };
                ClientManager.send(payload);
            });
        } catch (Exception sendEx) {
            LOGGER.error("异常通知发送失败, channelId:{}", channelId, sendEx);
        } finally {
            closeChannel(ctx);
        }
    }

    protected abstract void read(ChannelHandlerContext ctx, T msg);

    private void initChannelData(ChannelHandlerContext ctx) {
        // 存入管道信息
        Channel channel = ctx.channel();
        String port = String.valueOf(((InetSocketAddress) channel.localAddress()).getPort());
        SocketConfigItem configItem = SocketServerManager.getSocketConfigItemByPort(port);
        ClientManager.add(channel.id().asLongText(), new ChannelData(configItem, channel, new JSONObject()));
    }

    /**
     * 运行业务逻辑
     * @param content 消息
     * @param remoteAddress 远程地址
     * @return 结果
     */
    protected Object runBusiness(ByteBuf content, String remoteAddress) {
        long beginTime = System.currentTimeMillis();
        SocketConfigItem configItem = ClientManager.getConfig();
        byte[] data = new byte[content.readableBytes()];
        content.readBytes(data);
        String realData;
        try {
            realData = switch (configItem.getDecodeType()) {
                case HEX -> ConvertTools.byteToHexStr(data);
                default -> ConvertTools.bytesToStr(data);
            };
        } catch (Exception e) {
            LOGGER.error("数据解析失败：", e);
            return null;
        }

        JSONObject params = new JSONObject();
        params.put("value", realData);
        params.put("address", remoteAddress);

        try {
            Object result = SpringUtils.getBean(ILogicServiceProxy.class).run(configItem.getLogicName(), params);
            long endTime = System.currentTimeMillis();
            handleLog(configItem.getLogicName(), params, null, endTime - beginTime);
            return result;
        } catch (Exception e) {
            if (e instanceof LogicException ex) {
                LOGGER.error("请求来源'{}',发生业务异常.\n{}", remoteAddress, ex.getStack());
            } else {
                LOGGER.error("请求来源'{}',发生服务端异常.", remoteAddress, e);
            }
            long endTime = System.currentTimeMillis();
            handleLog(configItem.getLogicName(), params, e, endTime - beginTime);
            throw e;
        }
    }

    /**
     * 关闭通道
     * @param ctx 通道处理器上下文
     */
    protected final void closeChannel(ChannelHandlerContext ctx) {
        // UDP通道单独处理：只记录日志，不关闭，以避免端口被关掉
        Channel channel = ctx.channel();
        if (channel != null && !(ctx.channel() instanceof DatagramChannel)) {
            try {
                ClientManager.remove(ctx.channel().id());
                ctx.close();
            } catch (Exception e) {
                LOGGER.error("关闭通道时发生异常", e);
            }
        }
    }

    protected void handleLog(String logicName, Object operParams, final Throwable e, long costTime) {
        SpringUtils.getBean(LogResolveService.class).resolveLog(
                this.getClass().getName(),
                "runBusiness",
                BusinessType.LOGIC.name(),
                STR."Socket调用Logic：\{logicName}",
                OperatorType.SYSTEM.name(),
                operParams.toString(),
                costTime,
                e
        );
    }

}

==> af-common-socket-2.14.30-sources.jar: com/af/v4/system/common/socket/core/channel/AbstractChannelHandler.java <==
package com.af.v4.system.common.socket.core.channel;

import com.af.v4.system.common.core.exception.LogicException;
import com.af.v4.system.common.core.proxy.logic.ILogicServiceProxy;
import com.af.v4.system.common.core.utils.SpringUtils;
import com.af.v4.system.common.log.enums.BusinessType;
import com.af.v4.system.common.log.enums.OperatorType;
import com.af.v4.system.common.log.service.LogResolveService;
import com.af.v4.system.common.plugins.core.ConvertTools;
import com.af.v4.system.common.socket.SocketServerManager;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.enums.MsgTypeEnum;
import com.af.v4.system.common.socket.core.client.ClientManager;
import java.nio.charset.StandardCharsets;
import io.netty.buffer.ByteBuf;
import io.netty.channel.Channel;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.handler.timeout.IdleState;
import io.netty.handler.timeout.IdleStateEvent;
import io.netty.channel.socket.DatagramChannel;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.InetSocketAddress;
import java.net.SocketAddress;

public abstract class AbstractChannelHandler<T> extends SimpleChannelInboundHandler<T> {

    private static final Logger LOGGER = LoggerFactory.getLogger(AbstractChannelHandler.class);

    /**
     * 通道创建就绪后触发
     * @param ctx 通道
     * @throws Exception 抛出
     */
    @Override
    public void channelActive(ChannelHandlerContext ctx) throws Exception {
        String channelId = ctx.channel().id().asLongText();
        SocketAddress socketAddress = ctx.channel().remoteAddress();
        String address;
        if (socketAddress == null) {
            address = "-";
        } else {
            address = socketAddress.toString();
        }
        LOGGER.info("channelId:{}, address:{}, 成功建立连接", channelId, address);
        initChannelData(ctx);
        super.channelActive(ctx);
    }

    /**
     * 当通道有读取事件时，会触发
     * @param ctx 通道
     * @param msg 消息
     */
    @Override
    protected final void channelRead0(ChannelHandlerContext ctx, T msg) {
        String channelId = ctx.channel().id().asLongText();
        LOGGER.info("channelId:{}, 收到消息", channelId);
        ScopedValue.where(ClientManager.getChannelScopedValue(), channelId).run(() -> {
            if (ClientManager.getChannelData() == null) {
                initChannelData(ctx);
            }
            // 执行读方法
            read(ctx, msg);
        });
    }

    @Override
    public void channelInactive(ChannelHandlerContext ctx) throws Exception {
        LOGGER.info("channelId:{}, 触发断线", ctx.channel().id().asLongText());
        closeChannel(ctx);
        super.channelInactive(ctx);
    }

    @Override
    public void userEventTriggered(ChannelHandlerContext ctx, Object evt) throws Exception {
        if (evt instanceof IdleStateEvent idleStateEvent) {
            IdleState state = idleStateEvent.state();
            LOGGER.info("channelId:{}, 触发空闲断开事件:{}", ctx.channel().id().asLongText(), state);
            closeChannel(ctx);
        }
        super.userEventTriggered(ctx, evt);
    }

    /**
     * 处理异常, 一般是需要关闭通道
     * @param ctx 通道
     * @param cause 异常
     */
    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) {
        String channelId = ctx.channel().id().asLongText();
        String message;
        if (cause instanceof LogicException logicException) {
            message = logicException.getStack();
        } else {
            message = cause.getMessage();
        }
        LOGGER.error("channelId:{} 发生异常：{}", channelId, message);
        closeChannel(ctx);
    }

    protected abstract void read(ChannelHandlerContext ctx, T msg);

    private void initChannelData(ChannelHandlerContext ctx) {
        // 存入管道信息
        Channel channel = ctx.channel();
        String port = String.valueOf(((InetSocketAddress) channel.localAddress()).getPort());
        SocketConfigItem configItem = SocketServerManager.getSocketConfigItemByPort(port);
        ClientManager.add(channel.id().asLongText(), new ChannelData(configItem, channel, new JSONObject()));
    }

    /**
     * 运行业务逻辑
     * @param content 消息
     * @param remoteAddress 远程地址
     * @return 结果
     */
    protected Object runBusiness(ByteBuf content, String remoteAddress) {
        long beginTime = System.currentTimeMillis();
        SocketConfigItem configItem = ClientManager.getConfig();
        byte[] data = new byte[content.readableBytes()];
        content.readBytes(data);
        String realData;
        try {
            realData = switch (configItem.getDecodeType()) {
                case HEX -> ConvertTools.byteToHexStr(data);
                default -> ConvertTools.bytesToStr(data);
            };
        } catch (Exception e) {
            LOGGER.error("数据解析失败：", e);
            return null;
        }

        JSONObject params = new JSONObject();
        params.put("value", realData);
        params.put("address", remoteAddress);

        try {
            Object result = SpringUtils.getBean(ILogicServiceProxy.class).run(configItem.getLogicName(), params);
            long endTime = System.currentTimeMillis();
            handleLog(configItem.getLogicName(), params, null, endTime - beginTime);
            return result;
        } catch (Exception e) {
            if (e instanceof LogicException ex) {
                LOGGER.error("请求来源'{}',发生业务异常.\n{}", remoteAddress, ex.getStack());
            } else {
                LOGGER.error("请求来源'{}',发生服务端异常.", remoteAddress, e);
            }
            long endTime = System.currentTimeMillis();
            handleLog(configItem.getLogicName(), params, e, endTime - beginTime);
            throw e;
        }
    }

    /**
     * 关闭通道
     * @param ctx 通道处理器上下文
     */
    protected final void closeChannel(ChannelHandlerContext ctx) {
        // UDP通道单独处理：只记录日志，不关闭，以避免端口被关掉
        Channel channel = ctx.channel();
        if (channel != null && !(ctx.channel() instanceof DatagramChannel)) {
            try {
                ClientManager.remove(ctx.channel().id());
                ctx.close();
            } catch (Exception e) {
                LOGGER.error("关闭通道时发生异常", e);
            }
        }
    }

    protected void handleLog(String logicName, Object operParams, final Throwable e, long costTime) {
        SpringUtils.getBean(LogResolveService.class).resolveLog(
                this.getClass().getName(),
                "runBusiness",
                BusinessType.LOGIC.name(),
                STR."Socket调用Logic：\{logicName}",
                OperatorType.SYSTEM.name(),
                operParams.toString(),
                costTime,
                e
        );
    }

}
